**********************************************************
* Introduzione all'analisi dei dati longitudinali
* CAP 3:	ANALISI DEGLI EVENTI  
**********************************************************
* questa sintassi: 
* eha_intro.do
**********************************************************
* ESEMPI Cap 3.1 e 3.2 e 3.3 
* descrizione delle transizioni   
* confronto fra modelli  
* VERSIONE: AGOSTO 2013
***********************************************************
*version 12.1 
*ssc install stpiece
*adopath + A:\myadofiles

global eha F:\longi
set more off
set dp comma
use $eha\data\carriereIT_spell.dta, clear 
sort id ts 
drop if cnordsud==99
tab empstat
bys id: gen next=empstat[_n+1]
lab val next empstat
gen cens=next==.

** alcune ricodifiche **
bys id: gen nextstat=empstat[_n+1]  // come prima-- serve per l'esempio dopo
lab val nextstat empstat
bys id: gen nr=_n
tab empstat nr

gen cnord=cnordsud==0 
bys id: egen e=min(ts) 
recode e (942/1080=1989 ">1989") (1081/1176=1997 "1990-97") (1176/1200=1999 "1998-99") (1201/max=2005 "2000-05"), gen(ecoho)
tab ecoho
gen female=genere==2
recode casmin (110 120 130=1 "bassa") (220 231 232=2 "media") (310 320=3 "alta"), gen(educ) 
tab educ, gen(e)

rename cnordsud regione 

save $eha\data\carriereIT_spell_rec.dta, replace

** selezione dei disoccupati ** 
keep if empstat==21 
bys id: gen n_disoc=_n
recode n_disoc 3/7=3
tab n_disoc

** un file single episode soltanto per il primo episodio di disoccupazione 
keep if n_disoc==1
stset tf , failure(cens==0) id(id) origin(time ts) // nei file single episode l'id non serve, ma non fa neanche danni 


** ANALISI NON PARAMETRICA **
sts list

* Figura 3 
sts graph , survival by(regione) ci  tmax(62) xsize (5)   risktable (0(6)60)   ///
 xtitle("mesi", size(medium) margin(0 0 0 2))              ///
	   ytitle("% ancora disoccupati", size(medium))                  ///
 	   subtitle(" uscita dalla disoccupazione ", size(medium) )                       /// 
	   xlabel(0(12)60, labsize(medium))                              ///
	   ylabel(0(0.1)1, angle(0) labsize(medium) format(%3.1f))       ///
	   legend(pos(1) ring(0) row(2) order( 2 4) lab(2 "centro-nord") ///
		lab(4 "sud") size(small))     
 
** MODELLO SEMI-PARAMETRICO modello Cox
stcox cnord
stcox cnord, nohr
stcurve, at(cnord=0) at(cnord=1) surv range(0 62) ylabel(0(.2)1) name(cox, replace)
* plot dei risultati predetti sul modello 
* stcurve, haz
* stcurve, surv

/* l'importaza della ricodifica 
gen sud=regione==1
stcox sud
stcox sud, nohr
*/

** test per la proportiano hazard assumption 
estat phtest 
stphplot, by(regione) 
stcoxkm, by(regione) 
* Si veda anche: 
*		tvc(tvarlist) 
*		texp(exp)   fra le opzioni del stcox 



*** MODELLI PARAMETRICI ***
help streg
** esponenziale
streg cnord, dist(ex)
streg cnord, dist(ex) nohr
est store m1
streg cnord, dist(ex) time
streg cnord, dist(ex) time tr
stcurve, at(cnord=0) at(cnord=1) surv range(0 62)  name(e, replace)

** esponenziale piecewise  INSTALLARE ado prima

stpiece cnord , tp(0(12)60)

****//// START \\\*** 
****//// alcuni test e il modello esponenziale piecewise constant fatto manualmente \\\*** 
expand dur 
sort id ts 
bys id: gen t=_n
gen start=ts+1
replace start=ts[_n-1]+t if id==id[_n-1]
gen exit=0
replace exit=1 if next!=.&id!=id[_n+1]
gen p=t
recode p 0/12=1 13/24=2 25/36=3  37/48=4 49/60=5 61/max=6 
tab p, gen(Dp)
gen IA=p*cnord
gen tsq=t*t
stset start , failure(exit==1) id(id) origin(time ts)  // attenzione adesso si tratta di un file multi-spell
*stset t , failure(exit==1) id(id)  // questo riporta al medisomo risultato 

streg cnord, dist(ex)  // si vede che l'organizzazione dei dati non cambia il risultato. ma attenzione al stset!! 
streg cnord t,  dist(ex)
streg cnord t tsq,  dist(ex)
streg cnord t tsq IA,  dist(ex)
* il medesimo modello piecewise di sopra  a mano 
streg cnord Dp1-Dp6, nocons dist(ex)
****//// STOP \\\*** 

* da capo
use $eha\data\carriereIT_spell_rec.dta, clear 
keep if empstat==21 
bys id: gen n_disoc=_n
keep if n_disoc==1
stset tf , failure(cens==0) id(id) origin(time ts)


streg cnord, dist(wei) 
est store m2
streg cnord, dist(wei) nohr
stcurve, at(cnord=0) at(cnord=1) surv  range(0 62) name(wei, replace)
streg cnord, dist(wei) time
streg cnord, dist(wei) time tr

streg cnord, dist(ll) 
stcurve, at(cnord=0) at(cnord=1) surv   range(0 62)  name(ll, replace)

** figura 6, cap 3
*set scheme s2mono 

graph combine cox e wei ll 

lrtest m1 m2, force
   

	
		
		**///\\\**

**** MATERIALE NON TRATTATO NEL TESTO ***

stset tf , failure(next==11 12 13) id(id) origin(time ts) 
* considerando tutti episodi di disoccupazione per individuo. se ne ascia il MdL viene tolto dal risk set 
stset tf, failure(next==11 12 13) id(id) origin(time ts)  exit(next== 31 32 33)

set scheme s1mono 
set scheme s2color
 
sts graph , survival by(cnord) ci  tmax(60) xsize (5)      ///
 xtitle("mesi", size(medium) margin(0 0 0 2))              ///
	   ytitle("% ancora disoccupati", size(medium))                  ///
	   title("Disoccupazione: funzione di sopravvivenza ")                     ///
	   subtitle("  ", size(large) )                       ///
	   xlabel(0(10)60, labsize(medium))                              ///
	   ylabel(0(0.1)1, angle(0) labsize(medium) format(%3.1f))       ///
	   legend(pos(1) ring(0) row(2) order( 2 4) lab(2 "centro-nord") ///
		lab(4 "sud") size(small))     

sts graph , hazard by(cnord) ci  tmax(60)   
 ///
		
sts graph , hazard by(cnord) ci  tmax(60) xsize (5)    ///
 xtitle("mesi", size(medium) margin(0 0 0 2))              ///
	   ytitle("% ancora disoccupati", size(medium))                  ///
	   title("Disoccupazione: funzione di sopravvivenza ")                     ///
	   subtitle("  ", size(large) )                       ///
	   xlabel(0(10)60, labsize(medium))                              ///
	   ylabel(0(0.1)0.1, angle(0) labsize(medium) format(%3.1f))       ///
	   legend(pos(1) ring(0) row(2) order( 2 4) lab(2 "centro-nord") ///
		lab(4 "sud") size(small))     
