**********************************************************
* Introduzione all'analisi dei dati longitudinali
* CAP 3:	ANALISI DEGLI EVENTI  
**********************************************************
** FIGURA 5
* VERSIONE: AGOSTO 2013
*********************************************************
*version 12.1 



** Modello Weibull
*  r(t)= p*a*x^(p-1)   (alpha = 0.1, p varia) 

twoway                                                                                        /// 
(function y=0.1*0.8*x^(-0.2), range(0.0013 20) clwidth(*2) clcolor(blue) yvarlab("p=0.8"))   ///
(function y=0.1*1.2*x^(0.2),  range(0 20)      clwidth(*2) clcolor(green) yvarlab("p=1.2"))  ///
(function y=0.1*2*x,          range(0 1.5)     clwidth(*2) clcolor(red)  yvarlab("p=2.0")) ///
(function y=0.1*1*x^0,          range(0 20)     clwidth(*2) clcolor(gs45)  yvarlab("p=1.0")), ///
    xsize (4.5) title("Weibull: alpha=0.1, p varia", size(medium))                                   ///
    ylabel(0(.05).3, angle(0)  grid) ytitle("r(t)", size(medium))                 ///
    xlabel(0(5)20) xtitle("tempo", size(small) margin(0 0 0 2))  name(wei, replace)

* Modello LogLog 
*  r(t)= (l*p*(l*x)^p-1)/(1+(l*x)^p) (p = 2.5, gamma varia)
twoway                                                                                                               /// 
 (function y=(.10*2.5*(.10*x)^1.5)/(1+(.10*x)^2.5), range(0 20)   clwidth(*2) clcolor(blue) yvarlab("gamma=0.10"))  ///
 (function y=(.15*2.5*(.15*x)^1.5)/(1+(.15*x)^2.5), range(0 20)   clwidth(*2) clcolor(green) yvarlab("gamma=0.15")) ///
 (function y=(.20*2.5*(.20*x)^1.5)/(1+(.20*x)^2.5), range(0 20)   clwidth(*2) clcolor(red) yvarlab("gamma=0.20", small)),  ///
    xsize(4.5) title("Log-logistico: p=2.5, gamma varia", size(medium))                                                     ///
    ylabel(0(.05).3, angle(0) grid) ytitle("r(t)", size(medium))                                        ///
    xlabel(0(5)20) xtitle("tempo", size(small) margin(0 0 0 2))   name(ll, replace)                   


* Modello Gompertz  
*  r(t)= a+l^(pt)  ()
twoway                                                     /// 
 (function y=(0.03+.2^(.04*x)), range(0 20)   clwidth(*2) clcolor(blue) yvarlab("p=0.04"))  ///
 (function y=(.03+.2^(.02*x)), range(0 20)   clwidth(*2) clcolor(green) yvarlab("p=0.02")) ///
 (function y=(.03+.2^(-.02*x)), range(0 20)   clwidth(*2) clcolor(red) yvarlab("p=-0,02")),  ///
    xsize(4.5) title("Gompertz: a=0.03, lambda=0.2, p varia", size(medium))                                                     ///
	ylabel(0(.4)2, angle(0)  grid) ytitle("r(t)", size(medium))      ///
	xlabel(0(5)20) xtitle("tempo", size(small) margin(0 0 0 2))    name(gom, replace)
	
	
	  * piecewise constant  
*  r(t)= a+l^(pt)  ()
twoway                                                     /// 
 (function y=0.1, range(0 2)   clwidth(*2) clcolor(blue) yvarlab("0.1"))  ///
  (function y=0.2, range(3 5)   clwidth(*2) clcolor(blue) yvarlab("0.2"))  ///
   (function y=0.3, range(6 8)   clwidth(*2) clcolor(blue) yvarlab("0.3"))  ///
   	(function y=0.4, range( 9 10)   clwidth(*2) clcolor(blue) yvarlab("0.4"))  ///
  (function y=0.3, range(11 14)   clwidth(*2) clcolor(blue) yvarlab("0.3"))  ///
   (function y=0.1, range(15 20)   clwidth(*2) clcolor(blue) yvarlab("0.1")),  ///    
xsize(4.5) title("Esponenziale 'piecewiese constant'", size(medium))                              ///
	ylabel(0(.1)0.6, angle(0) grid) ytitle("r(t)", size(medium))      ///
	xlabel(0(5)20) xtitle("tempo", size(small) margin(0 0 0 2)) legend (order( 4 3 2 1))   name(pwe, replace)

graph combine pwe wei gom ll  
	

	** legend(pos(11) ring(0) rows(3) order(6 5 4 3 2 1) size(small))
** format(%3.2f) in: ylable 
